require(ggplot2); require(MCMCglmm)

d1 = data.frame(
       Assay.Run = factor( rep(1:6, each=5) ),
       Expected.RP=rep(c(60, 77, 100, 130, 167), 6),
       Observed.RP=c(51,	67,	90,	129,	153,
            50,	76,	97,	124,	176,
            55,	70,	99,	142,	157,
            61,	78,	107,	134,	172,
            60,	75,	101,	126,	160,
            65,	82,	104,	135,	174)
            )

d2 = data.frame(
       Assay.Run = factor( rep(1:6, each=5) ),
       Expected.RP=rep(c(60, 77, 100, 130, 167), 6),
       Observed.RP=c(64,	71,	95,	127,	151,
                     65,	75,	99,	120,	160,
                     66,	87,	106,	138,	180,
                     69,	85,	109,	126,	146,
                     55,	76,	95,  135,	155,
                     68,	72,	105,	145,	179)
                     )

d = rbind( data.frame(Assay="HTRF", d1), data.frame(Assay="AP1", d2) )


ggplot( d, aes( log(Expected.RP), log(Observed.RP)) ) + geom_point(size=1.5)+scale_shape(solid=FALSE) + facet_grid(~Assay) + theme_grey(base_size=12) +
      stat_smooth( data=d, aes( log(Expected.RP), log(Observed.RP) ), method=lm, linetype="dashed", colour="black",size=1, inherit.aes=FALSE) +
      xlab("Expected Relative Potency") + ylab("Observed Relative Potency") + scale_x_continuous( breaks=log(c(60, 77, 100, 130, 167)), labels=c(60, 77, 100, 130, 167) ) +
      scale_y_continuous( breaks=log(c(60, 77, 100, 130, 167)), labels=c(60, 77, 100, 130, 167) )+theme_bw( base_size=12 )


coef1 = do.call("rbind", by(d1, d1$Assay.Run, function(d0){
                     coef(lm( log(Observed.RP)~log(Expected.RP), data=d0 ))
                     }))
Vhat1 = var(coef1)
fit1 = MCMCglmm( log(Observed.RP)~log(Expected.RP), data=d1, random=~us(1+log(Expected.RP)):Assay.Run,
               prior=list(G=list(G1=list(V=Vhat1, nu=3))),
               thin=10, burnin=10000, nitt=10000+10*20000 )

coef2 = do.call("rbind", by(d2, d2$Assay.Run, function(d0){
                     coef(lm( log(Observed.RP)~log(Expected.RP), data=d0 ))
                     }))
Vhat2 = var(coef2)
fit2 = MCMCglmm( log(Observed.RP)~log(Expected.RP), data=d2, random=~us(1+log(Expected.RP)):Assay.Run,
               prior=list(G=list(G1=list(V=Vhat2, nu=3))),
               thin=10, burnin=10000, nitt=10000+10*20000 )

x.range = log( c(60, 167) )
delta = log(1.3)

## Test if means from fit1 and fit2 are equivalent across the entire x.range, equivalency = 30%
delta.95 = quantile(apply( cbind( abs( (fit1$Sol[,1]+fit1$Sol[,2]*x.range[1]) - (fit2$Sol[,1]+fit2$Sol[,2]*x.range[1]) ),
              abs( (fit1$Sol[,1]+fit1$Sol[,2]*x.range[2]) - (fit2$Sol[,1]+fit2$Sol[,2]*x.range[2]) )
              ), 1, max ), p=c(0.5, 0.9))
p.delta = mean( abs( (fit1$Sol[,1]+fit1$Sol[,2]*x.range[1]) - (fit2$Sol[,1]+fit2$Sol[,2]*x.range[1]) ) < delta &
                abs( (fit1$Sol[,1]+fit1$Sol[,2]*x.range[2]) - (fit2$Sol[,1]+fit2$Sol[,2]*x.range[2]) ) < delta
                )

####output coefficients and the 95% credible range





d.plot = data.frame( x=seq( log(60), log(167), length=35 ) )
mu = sapply(d.plot$x, function(x0){    quantile( (fit1$Sol[,1]+fit1$Sol[,2]*x0) - (fit2$Sol[,1]+fit2$Sol[,2]*x0), p=c(0.5, 0.05, 0.95) ) })
d.plot$Est = mu[1,]
d.plot$Lower = mu[2,]
d.plot$Upper = mu[3,]

ggplot( d.plot, aes(x, Est) ) + geom_line(size=1.5) +
      geom_hline( yintercept=c(-1, 1)*log(1.3), size=1.5 ) +
      geom_line( data=d.plot, aes(x, Lower),  linetype="dashed", size=1.5 ) +
      geom_line( data=d.plot, aes(x, Upper),  linetype="dashed", size=1.5 ) +
      xlab("Expected Relative Potency") + ylab("Mean Difference [ln scale]") + scale_x_continuous( breaks=log(c(60, 77, 100, 130, 167)), labels=c(60, 77, 100, 130, 167) ) +
      theme_grey(base_size=18)+theme_bw( base_size=12 )

